// Stan model code for the multi-level intercept-only model
// in the classic parametrization

// Supplementary material to article:
// Hecht, M., Weirich, S., & Zitzmann, S. (2021). Comparing the MCMC efficiency
//   of JAGS and Stan for the multi-level intercept-only model in the covariance-
//   and mean-based and classic parametrization. Psych.

data {
   int<lower=1> J;  // number of level 2 units
   int<lower=1> P;  // number of level 1 units
   matrix[P,J] D;   // data matrix   
}

parameters {
   real<lower=0> sigma2theta;
   real<lower=0> sigma2eps;
   real mu;
   vector[J] theta;
}

model {
   // loop over level 2 units
   for (j in 1:J) {
      // loop over level 1 units
      for (p in 1:P) {
         // distributional assumption of observations (Equation 1)
         D[p,j] ~ normal( theta[j], sigma2eps );
      }
      // distributional assumption of the person parameters (Equation 2)
      theta[j] ~ normal( mu, sigma2theta );
   }
   
   // prior distribution for mu
   mu ~ normal( 0, sqrt(10000) );
   
   // prior distribution for sigma2theta
   sigma2theta ~ inv_gamma(0.001,0.001);
   
   // prior distribution for sigma2eps   
   sigma2eps ~ inv_gamma(0.001,0.001);
}
